#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hunit
version: 0.9.2
id: tasty-hunit-0.9.2-e1d44484dc0859a198a89b637e3d5133
key: tasty_7kv5FhZVwprLclivJIQXzM
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
exposed-modules:
    Test.Tasty.HUnit
hidden-modules: Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-hunit-0.9.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-hunit-0.9.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/tasty-hunit-0.9.2
hs-libraries: HStasty-hunit-0.9.2-7kv5FhZVwprLclivJIQXzM
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    tasty-0.11.0.2-6ecf5c4c4584053c63756484aea2d9b8
haddock-interfaces: /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html: /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
